@@ -128,6 +128,7 @@ type MachineMount struct {
 	Path      string `json:"path"`
 	SizeGb    int    `json:"size_gb"`
 	Volume    string `json:"volume"`
+	Name      string `json:"name"`
 }
 
 type MachineGuest struct {
@@ -204,7 +205,7 @@ type MachineConfig struct {
 	Guest     *MachineGuest           `json:"guest,omitempty"`
 	Metrics   *MachineMetrics         `json:"metrics"`
 	Schedule  string                  `json:"schedule,omitempty"`
-	Network   MachineNetwork          `json:"network,omitempty"`
+	Network   *MachineNetwork         `json:"network,omitempty"`
 	Checks    map[string]MachineCheck `json:"checks,omitempty"`
 }
 
