@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/samber/lo"
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/client"
@@ -44,6 +45,10 @@ func newClone() *cobra.Command {
 			Name:        "name",
 			Description: "Optional name for the new machine",
 		},
+		flag.String{
+			Name:        "from-snapshot",
+			Description: "Clone attached volumes and restore from snapshot, use 'last' for most recent snapshot. The default is an empty volume",
+		},
 	)
 
 	return cmd
@@ -100,38 +105,60 @@ func runMachineClone(ctx context.Context) (err error) {
 
 	targetConfig := source.Config
 
-	// This is a temperary hack to add volume support for PG apps.
-	// Flaps does not currently specify the volume name within the Machine mount spec,
-	// which is required before we can handle this more generally.
-	if app.PostgresAppRole != nil && app.PostgresAppRole.Name == "postgres_cluster" {
-		if len(source.Config.Mounts) > 0 {
-			mnt := source.Config.Mounts[0]
-
-			volInput := api.CreateVolumeInput{
-				AppID:             app.ID,
-				Name:              "pg_data",
-				Region:            region,
-				SizeGb:            mnt.SizeGb,
-				Encrypted:         mnt.Encrypted,
-				RequireUniqueZone: false,
-			}
-
-			vol, err := client.CreateVolume(ctx, volInput)
+	for _, mnt := range source.Config.Mounts {
+		volName := mnt.Name
+		if mnt.Name == "" {
+			// Fallback for mounts that doesn't have pool name set
+			vol, err := client.GetVolume(ctx, mnt.Volume)
 			if err != nil {
 				return err
 			}
+			volName = vol.Name
+		}
 
-			targetConfig.Mounts = []api.MachineMount{
-				{
-					Volume:    vol.ID,
-					Path:      mnt.Path,
-					SizeGb:    mnt.SizeGb,
-					Encrypted: mnt.Encrypted,
-				},
+		var snapshotID *string
+		switch snapID := flag.GetString(ctx, "from-snapshot"); snapID {
+		case "last":
+			snapshots, err := client.GetVolumeSnapshots(ctx, mnt.Volume)
+			if err != nil {
+				return err
 			}
+			if len(snapshots) > 0 {
+				snapshot := lo.MaxBy(snapshots, func(i, j api.Snapshot) bool { return i.CreatedAt.After(j.CreatedAt) })
+				snapshotID = &snapshot.ID
+				fmt.Fprintf(out, "Creating new volume from snapshot %s of %s\n", colorize.Bold(*snapshotID), colorize.Bold(mnt.Volume))
+			} else {
+				fmt.Fprintf(out, "No snapshot for source volume %s, the new volume will start empty\n", colorize.Bold(mnt.Volume))
+				snapshotID = nil
+			}
+		case "":
+			fmt.Fprintf(out, "Volume '%s' will start empty\n", colorize.Bold(volName))
+		default:
+			snapshotID = &snapID
+		}
+
+		volInput := api.CreateVolumeInput{
+			AppID:             app.ID,
+			Name:              volName,
+			Region:            region,
+			SizeGb:            mnt.SizeGb,
+			Encrypted:         mnt.Encrypted,
+			SnapshotID:        snapshotID,
+			RequireUniqueZone: false,
+		}
+		vol, err := client.CreateVolume(ctx, volInput)
+		if err != nil {
+			return err
+		}
+
+		targetConfig.Mounts = []api.MachineMount{
+			{
+				Volume:    vol.ID,
+				Path:      mnt.Path,
+				SizeGb:    mnt.SizeGb,
+				Encrypted: mnt.Encrypted,
+			},
 		}
-	} else {
-		targetConfig.Mounts = nil
 	}
 
 	input := api.LaunchMachineInput{
@@ -140,7 +167,6 @@ func runMachineClone(ctx context.Context) (err error) {
 		Region: region,
 		Config: targetConfig,
 	}
-
 	fmt.Fprintf(out, "Provisioning a new machine with image %s...\n", source.Config.Image)
 
 	launchedMachine, err := flapsClient.Launch(ctx, input)
