@@ -13,7 +13,6 @@ import (
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/apps"
 	"github.com/superfly/flyctl/internal/flag"
-	"github.com/superfly/flyctl/internal/machine"
 	mach "github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/iostreams"
 )
@@ -118,7 +117,7 @@ func machinesRestart(ctx context.Context, input *api.RestartMachineInput) (err e
 
 	// Restarting replicas
 	for _, replica := range replicas {
-		if err = machine.Restart(ctx, replica, input); err != nil {
+		if err = mach.Restart(ctx, replica, input); err != nil {
 			return err
 		}
 	}
@@ -145,7 +144,7 @@ func machinesRestart(ctx context.Context, input *api.RestartMachineInput) (err e
 		}
 	}
 
-	if err = machine.Restart(ctx, leader, input); err != nil {
+	if err = mach.Restart(ctx, leader, input); err != nil {
 		return err
 	}
 
